@@ -785,6 +785,30 @@ def make_configclass(cls_name, fields, *, bases=(), namespace=None, init=True,
                        unsafe_hash=unsafe_hash, frozen=frozen)
 
 
+def merge_fields(dest_cls, *src_classes):
+    for src_cls in src_classes:
+        src_fields = getattr(src_cls, _FIELDS, None)
+        dest_fields = getattr(dest_cls, _FIELDS, {})
+
+        for f in src_fields.values():
+            dest_fields[f.name] = f
+
+            setattr(dest_cls, f.name, f.default)
+
+        # setattr(dest_cls, _FIELDS, dest_fields)
+
+    return dest_cls
+
+
+def export(from_obj, to_obj_or_class):
+    to_fields = fields(to_obj_or_class)
+    to_obj = to_obj_or_class() if type(to_obj_or_class) == type else to_obj_or_class
+    for f in to_fields:
+        if hasattr(from_obj, f.name):
+            setattr(to_obj, f.name, getattr(from_obj, f.name))
+    return to_obj
+
+
 def replace(obj, **changes):
     if not _is_configclass_instance(obj):
         raise TypeError("replace() should be called on configclass instances")
